@@ -2,7 +2,7 @@
 from wtracker.app import app
 
 def main():
-  app.run()
+  app.run(debug=True, host='0.0.0.0')
 
 if __name__ == "__main__":
   main()
\ No newline at end of file
